@@ -5,7 +5,7 @@ test_that("Uncensored data can be coloured by group", {
   p <- suppressMessages(group_cdf_uncensored(data, p))
   expect_s3_class(p, "ggplot")
 
-  group_p <- p$layers[[1]]$data$group[order(p$layers[[1]]$data$group)]
+  group_p <- p$layers$geom_point$data$group[order(p$layers$geom_point$data$group)]
 
   group <- data$group[order(data$group)]
   expect_identical(group_p, group)
